"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
class BaseCommand extends command_1.Command {
    static getNetworksInfo() {
        return {
            kovan: { url: 'https://kovan.infura.io', id: 42, label: 'Kovan' },
            mainnet: { url: 'https://mainnet.infura.io', id: 1, label: 'Mainnet' },
            poa: { url: 'https://core.poa.network', id: 99, label: 'POA' },
            rinkeby: { url: 'https://rinkeby.infura.io', id: 4, label: 'Rinkeby' },
            ropsten: { url: 'https://ropsten.infura.io', id: 3, label: 'Ropsten' },
            rsk: { url: 'https://public-node.rsk.co', id: 30, label: 'RSK' },
            'rsk-testnet': { url: 'https://public-node.testnet.rsk.co', id: 31, label: 'RSK testnet' },
            sokol: { url: 'https://sokol.poa.network', id: 77, label: 'Sokol' },
            xdai: { url: 'https://dai.poa.network', id: 100, label: 'xDAI' },
        };
    }
    getNetworkUrl(flags) {
        const [networkUrl] = this.getNetworkUrlAndFlag(flags);
        return networkUrl;
    }
    getNetworkUrlAndFlag(flags) {
        if (flags.url) {
            return [flags.url, 'url'];
        }
        const networksInfo = BaseCommand.getNetworksInfo();
        for (const flag of Object.keys(flags)) {
            if (flag === 'url' || !BaseCommand.flags[flag])
                continue;
            if (flags[flag]) {
                return [networksInfo[flag].url, flag];
            }
        }
        return [BaseCommand.defaultUrl, 'url'];
    }
}
BaseCommand.flags = {
    url: command_1.flags.string(),
    mainnet: command_1.flags.boolean({ exclusive: ['url'] }),
    ropsten: command_1.flags.boolean({ exclusive: ['url'] }),
    rinkeby: command_1.flags.boolean({ exclusive: ['url'] }),
    rsk: command_1.flags.boolean({ exclusive: ['url'] }),
    'rsk-testnet': command_1.flags.boolean({ exclusive: ['url'] }),
    kovan: command_1.flags.boolean({ exclusive: ['url'] }),
    sokol: command_1.flags.boolean({ exclusive: ['url'] }),
    poa: command_1.flags.boolean({ exclusive: ['url'] }),
    xdai: command_1.flags.boolean({ exclusive: ['url'] }),
};
BaseCommand.defaultUrl = 'http://localhost:8545';
exports.BaseCommand = BaseCommand;
