"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
class DeployCommand extends base_1.BaseCommand {
    async run() {
        const { args, flags } = this.parse(DeployCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { bin, pk } = args;
            const { deploy } = await Promise.resolve().then(() => __importStar(require('../../helpers/deploy')));
            const data = await deploy(networkUrl, pk, bin);
            cli_ux_1.cli.styledJSON(data);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
DeployCommand.description = `Deploy contract whose bytecode is in <bin> using private key <pk>.`;
DeployCommand.flags = Object.assign({}, base_1.BaseCommand.flags);
DeployCommand.args = [
    {
        name: 'pk',
        required: true,
        description: 'The private key.',
    },
    {
        name: 'bin',
        required: true,
        description: 'The bin file of the contract.',
    },
];
DeployCommand.examples = [
    'eth contract:deploy --ropsten 3daa79a26454a5528a3523f9e6345efdbd636e63f8c24a835204e6ccb5c88f9e ./contracts/proxy.bin',
];
DeployCommand.aliases = ['ct:d', 'ct:deploy'];
exports.DeployCommand = DeployCommand;
