"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const flags_1 = require("../../flags");
class SendTransactionCommand extends base_1.BaseCommand {
    async run() {
        const { args, flags } = this.parse(SendTransactionCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { encodedABI, address } = args;
            const { pk } = flags;
            const { sendTransaction } = await Promise.resolve().then(() => __importStar(require('../../helpers/sendTransaction')));
            const result = await sendTransaction(encodedABI, address, pk, networkUrl);
            cli_ux_1.cli.styledJSON(result);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
SendTransactionCommand.description = `Sends the transaction for the contract in <address> with <encodedABI> using the given private key.`;
SendTransactionCommand.flags = Object.assign({}, base_1.BaseCommand.flags, { pk: Object.assign({}, flags_1.privateKeyFlag, { required: true }) });
SendTransactionCommand.args = [
    {
        name: 'encodedABI',
        required: true,
        description: 'The encoded ABI.',
    },
    {
        name: 'address',
        required: true,
        description: `The contract's address.`,
    },
];
SendTransactionCommand.examples = [
    'eth method:send-transaction --pk 0x6db0bdfc7800dcf87b5a88b3363997360395d36ef51db10c3458d51d8aefd37e 0xa9059cbb000000000000000000000000b2e4a264a982039f8e503ea3c83af5537f583069000000000000000000000000da480b4852ca3ade4acf3eeca6901952edbae912 0x15503FBAb2fa57535092ab9c24740142Ab6cabd3',
];
SendTransactionCommand.aliases = ['m:st'];
exports.default = SendTransactionCommand;
