"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../base");
const flags_1 = require("../../flags");
class SendCommand extends base_1.BaseCommand {
    async run() {
        const { args, flags } = this.parse(SendCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { abi, methodCall, address } = args;
            const { pk } = flags;
            const { encode } = await Promise.resolve().then(() => __importStar(require('../../helpers/encode')));
            const { sendTransaction } = await Promise.resolve().then(() => __importStar(require('../../helpers/sendTransaction')));
            const abiByteCode = encode(abi, methodCall, networkUrl);
            const result = await sendTransaction(abiByteCode, address, pk, networkUrl);
            cli_ux_1.cli.styledJSON(result);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
SendCommand.description = `Executes <methodCall> for the contract in <address> given <abi> using the given private key.`;
SendCommand.flags = Object.assign({}, base_1.BaseCommand.flags, { pk: Object.assign({}, flags_1.privateKeyFlag, { required: true }) });
SendCommand.args = [
    {
        name: 'abi',
        required: true,
        description: `The contract's ABI.`,
    },
    {
        name: 'methodCall',
        required: true,
        description: `e.g.: 'myMethod(arg1,arg2,["a","b",3,["d","0x123..."]])'`,
    },
    {
        name: 'address',
        required: true,
        description: `The contract's  address.`,
    },
];
SendCommand.examples = [
    `eth method:send erc20 'transfer("0xb2E4a264A982039f8E503ea3C83af5537f583069", "0xDa480B4852ca3aDE4acF3eeCA6901952EdbAe912")' 0x15503FBAb2fa57535092ab9c24740142Ab6cabd3 0x6db0bdfc7800dcf87b5a88b3363997360395d36ef51db10c3458d51d8aefd37e`,
];
SendCommand.aliases = ['m:s'];
exports.default = SendCommand;
