"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const index_1 = require("../base/index");
class NetworksCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(NetworksCommand);
        const { table } = flags;
        const networkConstants = index_1.BaseCommand.getNetworksInfo();
        if (!table) {
            cli_ux_1.cli.styledJSON(networkConstants);
        }
        else {
            const networks = Object.values(networkConstants).sort((network1, network2) => {
                if (network1.id !== undefined && network2.id !== undefined) {
                    return network1.id - network2.id;
                }
                else if (network1.id !== undefined) {
                    return -1;
                }
                else {
                    return 1;
                }
            });
            cli_ux_1.cli.table(networks, {
                id: {
                    header: 'Id',
                    minWidth: 7,
                },
                label: {
                    header: 'Name',
                },
                url: {
                    header: 'Url',
                },
            }, Object.assign({ printLine: this.log }, flags));
        }
    }
}
NetworksCommand.description = `Show information for each known network.`;
NetworksCommand.flags = {
    json: command_1.flags.boolean({
        description: 'Display data in a json structure.',
        required: false,
        exclusive: ['table'],
    }),
    table: command_1.flags.boolean({
        description: 'Display data in a table structure.',
        required: false,
        exclusive: ['json'],
    }),
};
NetworksCommand.examples = ['eth networks --display json'];
exports.default = NetworksCommand;
