"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lodash_camelcase_1 = tslib_1.__importDefault(require("lodash.camelcase"));
const path = tslib_1.__importStar(require("path"));
const web3_1 = tslib_1.__importDefault(require("web3"));
const replStarter_1 = require("./replStarter");
const utils_1 = require("./utils");
async function startRepl(url, prompt, contracts, privateKey) {
    if (!url) {
        throw new Error('[startRepl] URL require');
    }
    // Connect web3
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    if (privateKey) {
        web3.eth.accounts.wallet.add(privateKey);
    }
    // Default context
    let replContext = {
        web3,
        eth: web3.eth,
    };
    const loadedContracts = {};
    const addContract = (abiPath, address, replContext) => {
        const abi = utils_1.loadABI(abiPath);
        const transactionConfirmationBlocks = 3;
        const options = {
            transactionConfirmationBlocks,
        };
        const Contract = web3.eth.Contract; // ts hack: transactionConfirmationBlocks is not a valid option
        const contractInstance = new Contract(abi, address, options);
        let [contractName] = path.basename(abiPath).split('.');
        let contractNameCamelCased = lodash_camelcase_1.default(contractName);
        if (replContext[contractNameCamelCased]) {
            const suffix = Object.keys(replContext).filter(function (key) {
                return key.includes(contractNameCamelCased);
            }).length;
            contractNameCamelCased = [contractNameCamelCased, '_', suffix].join('');
        }
        replContext[contractNameCamelCased] = contractInstance;
        loadedContracts[contractNameCamelCased] = address;
    };
    // Add contracts into context
    for (let contract of contracts) {
        addContract(contract.abiPath, contract.address, replContext);
    }
    const accounts = await web3.eth.getAccounts();
    replContext.accounts = accounts;
    // Start REPL
    const r = replStarter_1.replStarter(replContext, prompt);
    r.defineCommand('contracts', {
        help: 'Show loaded contracts',
        action() {
            this.clearBufferedCommand();
            for (const [loadedContract, address] of Object.entries(loadedContracts)) {
                console.log(`${loadedContract} (${address})`);
            }
            this.displayPrompt();
        },
    });
    r.defineCommand('loadc', {
        help: 'Load a contract using the specified ABI and address',
        action(abiAndAddress) {
            this.clearBufferedCommand();
            const [abiPath, address] = abiAndAddress.split('@');
            addContract(abiPath, address, r.context);
            this.displayPrompt();
        },
    });
}
exports.startRepl = startRepl;
